aboutsummaryrefslogtreecommitdiff
path: root/src/client/shadows/dynamicshadows.h
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--src/client/shadows/dynamicshadows.h8
1 files changed, 7 insertions, 1 deletions
diff --git a/src/client/shadows/dynamicshadows.h b/src/client/shadows/dynamicshadows.h
index 70574aa6c..6e9d96b15 100644
--- a/src/client/shadows/dynamicshadows.h
+++ b/src/client/shadows/dynamicshadows.h
@@ -69,12 +69,18 @@ public:
const core::matrix4 &getFutureProjectionMatrix() const;
core::matrix4 getViewProjMatrix();
/// Gets the light's far value.
f32 getMaxFarValue() const
{
return farPlane * BS;
}
+ /// Gets the current far value of the light
+ f32 getFarValue() const
+ {
+ return shadow_frustum.zFar;
+ }
+
/// Gets the light's color.
const video::SColorf &getLightColor() const
@@ -69,12 +69,18 @@ public:
const core::matrix4 &getFutureProjectionMatrix() const;
core::matrix4 getViewProjMatrix();
- /// Gets the light's far value.
+ /// Gets the light's maximum far value, i.e. the shadow boundary
f32 getMaxFarValue() const
{